StatusCode

Enum StatusCode 

#[repr(u16)]
pub enum StatusCode {
Show 32 variants OK = 100, Ignored = 101, CompactBlockIsAlreadyPending = 102, CompactBlockIsAlreadyInFlight = 103, CompactBlockAlreadyStored = 104, CompactBlockIsStaled = 105, CompactBlockRequiresParent = 106, CompactBlockRequiresFreshTransactions = 107, CompactBlockMeetsShortIdsCollision = 108, BlocksInFlightReachLimit = 109, TooManyRequests = 110, ProtocolMessageIsMalformed = 400, BlockIsInvalid = 401, CompactBlockHasInvalidHeader = 402, CompactBlockHasDuplicatedShortIds = 403, CompactBlockHasNotPrefilledCellbase = 404, CompactBlockHasDuplicatedPrefilledTransactions = 405, CompactBlockHasOutOfOrderPrefilledTransactions = 406, CompactBlockHasOutOfIndexPrefilledTransactions = 407, CompactBlockHasInvalidUncle = 408, CompactBlockHasUnmatchedTransactionRootWithReconstructedBlock = 409, BlockTransactionsLengthIsUnmatchedWithPendingCompactBlock = 410, BlockTransactionsShortIdsAreUnmatchedWithPendingCompactBlock = 411, BlockUnclesLengthIsUnmatchedWithPendingCompactBlock = 412, BlockUnclesAreUnmatchedWithPendingCompactBlock = 413, GetHeadersMissCommonAncestors = 414, HeadersIsInvalid = 415, TooManyUnknownTransactions = 416, RequestGenesis = 417, RequestDuplicate = 418, TxPool = 501, Network = 502,
}
StatusCodes indicate whether a specific operation has been successfully completed. The StatusCode element is a 3-digit integer.

The first digest of the StatusCode defines the class of result:

  • 1xx: Informational - Request received, continuing process
  • 4xx: Malformed Error - The request contains malformed messages
  • 5xx: Warning - The node warns about recoverable conditions

Variants



OK = 100

OK



Ignored = 101

Ignored



CompactBlockIsAlreadyPending = 102

The node had already received and recorded this block as pending block



CompactBlockIsAlreadyInFlight = 103

The node is requesting from other peers for this block, but no response yet



CompactBlockAlreadyStored = 104

The node had already stored this block into database



CompactBlockIsStaled = 105

The CompactBlock is older than what the node expects



CompactBlockRequiresParent = 106

The node cannot process the arrived CompactBlock successfully for lack of information of its parent



CompactBlockRequiresFreshTransactions = 107

The node cannot process the arrived CompactBlock successfully for lack of parts of its transactions



CompactBlockMeetsShortIdsCollision = 108

CompactBlock short-ids collision



BlocksInFlightReachLimit = 109

In-flight blocks limit exceeded



TooManyRequests = 110

Generic rate limit error



ProtocolMessageIsMalformed = 400

Malformed protocol message



BlockIsInvalid = 401

Block verified failed or the block is already marked as invalid



CompactBlockHasInvalidHeader = 402

Header verified failed or the header is already marked as invalid



CompactBlockHasDuplicatedShortIds = 403

Duplicated short-ids within a same CompactBlock



CompactBlockHasNotPrefilledCellbase = 404

Missing cellbase as the first transaction within a CompactBlock



CompactBlockHasDuplicatedPrefilledTransactions = 405

Duplicated prefilled transactions within a same CompactBlock



CompactBlockHasOutOfOrderPrefilledTransactions = 406

The prefilled transactions are out-of-order



CompactBlockHasOutOfIndexPrefilledTransactions = 407

Some of the prefilled transactions are out-of-index



CompactBlockHasInvalidUncle = 408

Invalid uncle block



CompactBlockHasUnmatchedTransactionRootWithReconstructedBlock = 409

Unmatched Transaction Root



BlockTransactionsLengthIsUnmatchedWithPendingCompactBlock = 410

The length of BlockTransactions is unmatched with in pending_compact_blocks



BlockTransactionsShortIdsAreUnmatchedWithPendingCompactBlock = 411

The short-ids of BlockTransactions is unmatched with in pending_compact_blocks



BlockUnclesLengthIsUnmatchedWithPendingCompactBlock = 412

The length of BlockUncles is unmatched with in pending_compact_blocks



BlockUnclesAreUnmatchedWithPendingCompactBlock = 413

The hash of uncles is unmatched



GetHeadersMissCommonAncestors = 414

Cannot locate the common blocks based on the GetHeaders



HeadersIsInvalid = 415

Headers verified failed



TooManyUnknownTransactions = 416

Too many unknown transactions



RequestGenesis = 417

Request Genesis



RequestDuplicate = 418

Request Duplicate data



TxPool = 501

Errors returned from the tx-pool



Network = 502

Errors returned from the network layer

Implementations

Source

impl StatusCode

pub fn with_context<S: ToString>(self, context: S) -> Status

Code with context

pub fn name(self) -> String

StatusCode’s name like Ok(100)