pub struct SyncShared { /* private fields */ }
Sync state shared between sync and relayer protocol

Implementations

only use on test

Generate a global sync state through configuration

Shared chain db/config

Get snapshot with current chain

Get chain store

Get sync state

Get consensus config

Insert new block to chain store

Try to find blocks from the orphan block pool that may no longer be orphan

Sync a new valid header, try insert to sync state

Get header view with hash

Check whether block has been inserted to chain store

Get epoch ext by block hash